@@ -23,9 +23,12 @@ install_requirements(){
     # TODO: if not [automake --version]
     if [ "$os" == "Linux" ]; then
         if [ "$(grep -Ei 'debian|buntu|mint' /etc/*release)" ]; then
-            $sudo apt-get update && $sudo apt-get install -y build-essential curl python3-devel libmecab-dev git
+            $sudo apt-get update
+            $sudo apt-get install -y build-essential curl python3-devel libmecab-dev git
+            $sudo apt-key adv --keyserver keyserver.ubuntu.com --recv-keys A4B469963BF863CC
         elif [ "$(grep -Ei 'fedora|redhat' /etc/*release)" ]; then
-            $sudo yum groupinstall -y 'Development Tools' 'Development Libraries' && $sudo yum install -y curl python3-devel  git
+            $sudo yum groupinstall -y 'Development Tools' 'Development Libraries'
+            $sudo yum install -y curl python3-devel  git
         fi
     elif [ "$os" == "Darwin" ]; then
         if [[ $(command -v brew) == "" ]]; then
